==> seedsui-react-5.6.78.tgz: package/lib/Modal/Modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["portal", "animation", "sourceDOM", "visible", "maskClosable", "onVisibleChange", "maskProps", "captionProps", "submitProps", "cancelProps", "children"],
  _excluded2 = ["caption"],
  _excluded3 = ["caption", "onClick"],
  _excluded4 = ["caption", "onClick"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useImperativeHandle, useRef, forwardRef, useEffect } from 'react';
import { createPortal } from 'react-dom';
import TooltipUtils from "./../Tooltip/Utils";
import locale from "./../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var Modal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
    _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'zoom' : _ref$animation,
    _ref$sourceDOM = _ref.sourceDOM,
    sourceDOM = _ref$sourceDOM === void 0 ? null : _ref$sourceDOM,
    visible = _ref.visible,
    _ref$maskClosable = _ref.maskClosable,
    maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
    onVisibleChange = _ref.onVisibleChange,
    _ref$maskProps = _ref.maskProps,
    maskProps = _ref$maskProps === void 0 ? {} : _ref$maskProps,
    _ref$captionProps = _ref.captionProps,
    captionProps = _ref$captionProps === void 0 ? {} : _ref$captionProps,
    _ref$submitProps = _ref.submitProps,
    submitProps = _ref$submitProps === void 0 ? {} : _ref$submitProps,
    _ref$cancelProps = _ref.cancelProps,
    cancelProps = _ref$cancelProps === void 0 ? {} : _ref$cancelProps,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 增加保护
  /* eslint-disable */
  if (!maskProps) maskProps = {};
  if (!captionProps) captionProps = {};
  if (!submitProps) submitProps = {};
  if (!cancelProps) cancelProps = {};
  /* eslint-enable */

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  useEffect(function () {
    // 更新模态框位置对齐目标元素
    updateModalPosition();
    // eslint-disable-next-line
  }, [visible]);

  // 受控显隐时, 需要更新容器位置
  function updateModalPosition() {
    var _maskProps, _maskProps$style, _maskProps2, _maskProps2$style;
    var maskDOM = rootRef === null || rootRef === void 0 ? void 0 : rootRef.current;
    // eslint-disable-next-line
    if (typeof sourceDOM === 'function') sourceDOM = sourceDOM();
    if (!sourceDOM || !maskDOM) return;
    if (visible && sourceDOM && maskDOM && !((_maskProps = maskProps) !== null && _maskProps !== void 0 && (_maskProps$style = _maskProps.style) !== null && _maskProps$style !== void 0 && _maskProps$style.top) && !((_maskProps2 = maskProps) !== null && _maskProps2 !== void 0 && (_maskProps2$style = _maskProps2.style) !== null && _maskProps2$style !== void 0 && _maskProps2$style.bottom)) {
      TooltipUtils.updateContainerPosition({
        source: sourceDOM,
        target: maskDOM,
        animation: animation
      });
    }
  }

  // 构建动画
  var position = TooltipUtils.getAnimationPosition(animation);

  // 判断是否是要生成Alert框
  function getIsAlert() {
    var _captionProps = captionProps,
      titleText = _captionProps.caption;
    var _cancelProps = cancelProps,
      cancelText = _cancelProps.caption,
      cancelClick = _cancelProps.onClick;
    var _submitProps = submitProps,
      submitText = _submitProps.caption,
      submitClick = _submitProps.onClick;
    if (titleText || cancelText || cancelClick || submitText || submitClick) return true;
    return false;
  }

  // 获取内容
  function getChildren() {
    // 标题
    var caption = null;
    var _captionProps2 = captionProps,
      titleText = _captionProps2.caption,
      otherCaptionProps = _objectWithoutProperties(_captionProps2, _excluded2);
    if (titleText) {
      caption = /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCaptionProps), {}, {
        className: "modal-caption".concat(otherCaptionProps.className ? ' ' + otherCaptionProps.className : ''),
        children: titleText
      }));
    }

    // 底部
    var footer = [];

    // 取消
    var _cancelProps2 = cancelProps,
      cancelText = _cancelProps2.caption,
      cancelClick = _cancelProps2.onClick,
      otherCancelProps = _objectWithoutProperties(_cancelProps2, _excluded3);
    if (cancelText || cancelClick) {
      footer.push( /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
        onClick: handleCancel
      }, otherCancelProps), {}, {
        className: "modal-cancel button".concat(otherCancelProps.className ? ' ' + otherCancelProps.className : ''),
        children: cancelText || locale('取消', 'cancel')
      }), "footer-cancel"));
    }

    // 确定
    var _submitProps2 = submitProps,
      submitText = _submitProps2.caption,
      submitClick = _submitProps2.onClick,
      otherSubmitProps = _objectWithoutProperties(_submitProps2, _excluded4);
    if (submitText || submitClick) {
      footer.push( /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
        onClick: handleSubmit
      }, otherSubmitProps), {}, {
        className: "modal-ok button".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : ''),
        children: submitText || locale('确定', 'ok')
      }), "footer-ok"));
    }
    if (footer.length) {
      footer = /*#__PURE__*/_jsx("div", {
        className: "modal-footer",
        children: footer
      });
    } else {
      footer = null;
    }

    // 有标题或者有底部时
    if (caption || footer) {
      return /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsxs("div", {
          className: "modal-body",
          children: [caption, /*#__PURE__*/_jsx("div", {
            className: "modal-content",
            children: children
          })]
        }), footer]
      });
    }
    return children;
  }

  // 点击遮罩
  function handleMaskClick(e) {
    if (maskProps.onClick) maskProps.onClick(e);
    if (maskClosable && onVisibleChange) onVisibleChange(false);
    e.stopPropagation();
  }

  // 点击模态框
  function handleModalClick(e) {
    e.stopPropagation();
  }

  // 点击确定或者取消按钮
  function handleButton(e, buttonProps) {
    if (typeof (buttonProps === null || buttonProps === void 0 ? void 0 : buttonProps.onClick) === 'function') {
      var _buttonProps$onClick;
      var close = (_buttonProps$onClick = buttonProps.onClick()) !== null && _buttonProps$onClick !== void 0 ? _buttonProps$onClick : true;
      if (close) {
        if (onVisibleChange) onVisibleChange(false);
      }
    } else {
      if (onVisibleChange) onVisibleChange(false);
    }
    e.stopPropagation();
  }
  // 点击确定
  function handleSubmit(e) {
    handleButton(e, submitProps);
  }
  // 点击取消
  function handleCancel(e) {
    handleButton(e, cancelProps);
  }

  // 获取激活状态样式
  function getActiveClass() {
    return visible ? ' active' : '';
  }
  var ModalNode = /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
    className: "mask modal-mask".concat(maskProps.className ? ' ' + maskProps.className : '').concat(getActiveClass())
  }, maskProps), {}, {
    onClick: handleMaskClick,
    ref: rootRef,
    children: /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, props), {}, {
      className: "popup-animation modal".concat(getIsAlert() ? ' modal-alert' : '').concat(position ? ' ' + position : '').concat(props.className ? ' ' + props.className : '').concat(getActiveClass()),
      "data-animation": animation,
      onClick: handleModalClick,
      children: getChildren()
    }))
  }));
  if (portal === null || portal === false) {
    return ModalNode;
  }
  return /*#__PURE__*/createPortal(ModalNode, portal || document.getElementById('root') || document.body);
});
export default Modal;

==> seedsui-react-5.6.83.tgz: package/lib/Modal/Modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["portal", "animation", "sourceDOM", "visible", "maskClosable", "onVisibleChange", "maskProps", "captionProps", "submitProps", "cancelProps", "children"],
  _excluded2 = ["caption"],
  _excluded3 = ["caption", "onClick"],
  _excluded4 = ["caption", "onClick"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useImperativeHandle, useRef, forwardRef, useEffect } from 'react';
import { createPortal } from 'react-dom';
import TooltipUtils from "./../Tooltip/Utils";
import locale from "./../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var Modal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
    _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'zoom' : _ref$animation,
    _ref$sourceDOM = _ref.sourceDOM,
    sourceDOM = _ref$sourceDOM === void 0 ? null : _ref$sourceDOM,
    visible = _ref.visible,
    _ref$maskClosable = _ref.maskClosable,
    maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
    onVisibleChange = _ref.onVisibleChange,
    _ref$maskProps = _ref.maskProps,
    maskProps = _ref$maskProps === void 0 ? {} : _ref$maskProps,
    _ref$captionProps = _ref.captionProps,
    captionProps = _ref$captionProps === void 0 ? {} : _ref$captionProps,
    _ref$submitProps = _ref.submitProps,
    submitProps = _ref$submitProps === void 0 ? {} : _ref$submitProps,
    _ref$cancelProps = _ref.cancelProps,
    cancelProps = _ref$cancelProps === void 0 ? {} : _ref$cancelProps,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 增加保护
  /* eslint-disable */
  if (!maskProps) maskProps = {};
  if (!captionProps) captionProps = {};
  if (!submitProps) submitProps = {};
  if (!cancelProps) cancelProps = {};
  /* eslint-enable */

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  useEffect(function () {
    // 更新模态框位置对齐目标元素
    updateModalPosition();
    // eslint-disable-next-line
  }, [visible]);

  // 受控显隐时, 需要更新容器位置
  function updateModalPosition() {
    var _maskProps, _maskProps$style, _maskProps2, _maskProps2$style;
    var maskDOM = rootRef === null || rootRef === void 0 ? void 0 : rootRef.current;
    // eslint-disable-next-line
    if (typeof sourceDOM === 'function') sourceDOM = sourceDOM();
    if (!sourceDOM || !maskDOM) return;
    if (visible && sourceDOM && maskDOM && !((_maskProps = maskProps) !== null && _maskProps !== void 0 && (_maskProps$style = _maskProps.style) !== null && _maskProps$style !== void 0 && _maskProps$style.top) && !((_maskProps2 = maskProps) !== null && _maskProps2 !== void 0 && (_maskProps2$style = _maskProps2.style) !== null && _maskProps2$style !== void 0 && _maskProps2$style.bottom)) {
      TooltipUtils.updateContainerPosition({
        source: sourceDOM,
        target: maskDOM,
        animation: animation
      });
    }
  }

  // 构建动画
  var position = TooltipUtils.getAnimationPosition(animation);

  // 判断是否是要生成Alert框
  function getIsAlert() {
    var _captionProps = captionProps,
      titleText = _captionProps.caption;
    var _cancelProps = cancelProps,
      cancelText = _cancelProps.caption,
      cancelClick = _cancelProps.onClick;
    var _submitProps = submitProps,
      submitText = _submitProps.caption,
      submitClick = _submitProps.onClick;
    if (titleText || cancelText || cancelClick || submitText || submitClick) return true;
    return false;
  }

  // 获取内容
  function getChildren() {
    // 标题
    var caption = null;
    var _captionProps2 = captionProps,
      titleText = _captionProps2.caption,
      otherCaptionProps = _objectWithoutProperties(_captionProps2, _excluded2);
    if (titleText) {
      caption = /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCaptionProps), {}, {
        className: "modal-caption".concat(otherCaptionProps.className ? ' ' + otherCaptionProps.className : ''),
        children: titleText
      }));
    }

    // 底部
    var footer = [];

    // 取消
    var _cancelProps2 = cancelProps,
      cancelText = _cancelProps2.caption,
      cancelClick = _cancelProps2.onClick,
      otherCancelProps = _objectWithoutProperties(_cancelProps2, _excluded3);
    if (cancelText || cancelClick) {
      footer.push( /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
        onClick: handleCancel
      }, otherCancelProps), {}, {
        className: "modal-cancel button".concat(otherCancelProps.className ? ' ' + otherCancelProps.className : ''),
        children: cancelText || locale('取消', 'cancel')
      }), "footer-cancel"));
    }

    // 确定
    var _submitProps2 = submitProps,
      submitText = _submitProps2.caption,
      submitClick = _submitProps2.onClick,
      otherSubmitProps = _objectWithoutProperties(_submitProps2, _excluded4);
    if (submitText || submitClick) {
      footer.push( /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
        onClick: handleSubmit
      }, otherSubmitProps), {}, {
        className: "modal-ok button".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : ''),
        children: submitText || locale('确定', 'ok')
      }), "footer-ok"));
    }
    if (footer.length) {
      footer = /*#__PURE__*/_jsx("div", {
        className: "modal-footer",
        children: footer
      });
    } else {
      footer = null;
    }

    // 有标题或者有底部时
    if (caption || footer) {
      return /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsxs("div", {
          className: "modal-body",
          children: [caption, /*#__PURE__*/_jsx("div", {
            className: "modal-content",
            children: children
          })]
        }), footer]
      });
    }
    return children;
  }

  // 点击遮罩
  function handleMaskClick(e) {
    if (maskProps.onClick) maskProps.onClick(e);
    if (maskClosable && onVisibleChange) onVisibleChange(false);
    e.stopPropagation();
  }

  // 点击模态框
  function handleModalClick(e) {
    e.stopPropagation();
  }

  // 点击确定或者取消按钮
  function handleButton(e, buttonProps) {
    if (typeof (buttonProps === null || buttonProps === void 0 ? void 0 : buttonProps.onClick) === 'function') {
      var _buttonProps$onClick;
      var close = (_buttonProps$onClick = buttonProps.onClick()) !== null && _buttonProps$onClick !== void 0 ? _buttonProps$onClick : true;
      if (close) {
        if (onVisibleChange) onVisibleChange(false);
      }
    } else {
      if (onVisibleChange) onVisibleChange(false);
    }
    e.stopPropagation();
  }
  // 点击确定
  function handleSubmit(e) {
    handleButton(e, submitProps);
  }
  // 点击取消
  function handleCancel(e) {
    handleButton(e, cancelProps);
  }

  // 获取激活状态样式
  function getActiveClass() {
    return visible ? ' active' : '';
  }
  var ModalNode = /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, maskProps), {}, {
    className: "mask modal-mask".concat(maskProps.className ? ' ' + maskProps.className : '').concat(getActiveClass()),
    onClick: handleMaskClick,
    ref: rootRef,
    children: /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, props), {}, {
      className: "popup-animation modal".concat(getIsAlert() ? ' modal-alert' : '').concat(position ? ' ' + position : '').concat(props.className ? ' ' + props.className : '').concat(getActiveClass()),
      "data-animation": animation,
      onClick: handleModalClick,
      children: getChildren()
    }))
  }));
  if (portal === null || portal === false) {
    return ModalNode;
  }
  return /*#__PURE__*/createPortal(ModalNode, portal || document.getElementById('root') || document.body);
});
export default Modal;
